==> clms.downloadtool-3.4.zip: clms.downloadtool-3.4/src/clms/downloadtool/tests/test_restapi_delete_data.py <==
"""
Test the delete_data endpoint
"""
# -*- coding: utf-8 -*-
import unittest

import transaction
from plone.app.testing import (
    SITE_OWNER_NAME,
    SITE_OWNER_PASSWORD,
    TEST_USER_ID,
    setRoles,
)
from plone.restapi.testing import RelativeSession
from zope.component import getUtility

from clms.downloadtool.testing import CLMS_DOWNLOADTOOL_RESTAPI_TESTING
from clms.downloadtool.utility import IDownloadToolUtility


class TestDeleteData(unittest.TestCase):
    """ base class"""

    layer = CLMS_DOWNLOADTOOL_RESTAPI_TESTING

    def setUp(self):
        """Set up the test."""
        self.portal = self.layer["portal"]
        self.portal_url = self.portal.absolute_url()
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        self.api_session = RelativeSession(self.portal_url)
        self.api_session.headers.update({"Accept": "application/json"})
        self.api_session.auth = (SITE_OWNER_NAME, SITE_OWNER_PASSWORD)

        self.anonymous_session = RelativeSession(self.portal_url)
        self.anonymous_session.headers.update({"Accept": "application/json"})

    def tearDown(self):
        """ tear down cleanup"""
        self.api_session.close()
        self.anonymous_session.close()

    def test_delete_method_as_anonymous(self):
        """ test anonymous user cannot access datarequest_delete endpoint """
        response = self.anonymous_session.delete("@delete_data")
        self.assertEqual(
            response.headers.get("Content-Type"), "application/json"
        )
        self.assertEqual(response.status_code, 401)

    def test_delete_empty(self):
        """ test deleting an empty download registry"""
        response = self.api_session.delete("@delete_data")
        self.assertEqual(response.status_code, 400)

    def test_delete_all_data(self):
        """ delete all existing data"""
        utility = getUtility(IDownloadToolUtility)
        data_dict = {
            "UserId": "test_user",
            "TaskId": "test_task",
            "Status": "In_Progress",
        }
        utility.datarequest_post(data_dict)
        utility.datarequest_post(data_dict)
        utility.datarequest_post(data_dict)

        transaction.commit()

        response = self.api_session.delete("@delete_data")
        self.assertEqual(response.status_code, 204)

==> clms.downloadtool-5.7.zip: clms.downloadtool-5.7/src/clms/downloadtool/tests/test_restapi_delete_data.py <==
"""
Test the delete_data endpoint
"""
# -*- coding: utf-8 -*-
import unittest

import transaction
from clms.downloadtool.testing import CLMS_DOWNLOADTOOL_RESTAPI_TESTING
from clms.downloadtool.utility import IDownloadToolUtility
from plone.app.testing import (SITE_OWNER_NAME, SITE_OWNER_PASSWORD,
                               TEST_USER_ID, setRoles)
from plone.restapi.testing import RelativeSession
from zope.component import getUtility


class TestDeleteData(unittest.TestCase):
    """ base class"""

    layer = CLMS_DOWNLOADTOOL_RESTAPI_TESTING

    def setUp(self):
        """Set up the test."""
        self.portal = self.layer["portal"]
        self.portal_url = self.portal.absolute_url()
        setRoles(self.portal, TEST_USER_ID, ["Manager"])
        self.api_session = RelativeSession(self.portal_url)
        self.api_session.headers.update({"Accept": "application/json"})
        self.api_session.auth = (SITE_OWNER_NAME, SITE_OWNER_PASSWORD)

        self.anonymous_session = RelativeSession(self.portal_url)
        self.anonymous_session.headers.update({"Accept": "application/json"})

    def tearDown(self):
        """ tear down cleanup"""
        self.api_session.close()
        self.anonymous_session.close()

    def test_delete_method_as_anonymous(self):
        """ test anonymous user cannot access datarequest_delete endpoint """
        response = self.anonymous_session.delete("@delete_data")
        self.assertEqual(
            response.headers.get("Content-Type"), "application/json"
        )
        self.assertEqual(response.status_code, 401)

    def test_delete_empty(self):
        """ test deleting an empty download registry"""
        response = self.api_session.delete("@delete_data")
        self.assertEqual(response.status_code, 400)

    def test_delete_all_data(self):
        """ delete all existing data"""
        utility = getUtility(IDownloadToolUtility)
        data_dict = {
            "UserId": "test_user",
            "TaskId": "test_task",
            "Status": "In_Progress",
        }
        utility.datarequest_post(data_dict)
        utility.datarequest_post(data_dict)
        utility.datarequest_post(data_dict)

        transaction.commit()

        response = self.api_session.delete("@delete_data")
        self.assertEqual(response.status_code, 204)
